@@ -2,10 +2,10 @@
 #
 # Encoding of Arabic: ArabTeX Notation by Klaus Lagally #####################################
 
-# $Id: RE.pm 162 2006-12-16 00:16:10Z smrz $
-
 package Encode::Arabic::ArabTeX::RE;
 
+our $VERSION = '14.1';
+
 use 5.008;
 
 use strict;
@@ -13,9 +13,6 @@ use warnings;
 
 use Scalar::Util 'blessed';
 
-our $VERSION = do { q $Revision: 162 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
-
-
 use Encode::Encoding;
 use base 'Encode::Encoding';
 
@@ -49,6 +46,7 @@ our %modemap = (
 
 sub import {            # perform import as if Encode were used one level before this module
     require Encode;
+    push @Encode::ISA, 'Exporter' unless Encode->can('export_to_level');
     Encode->export_to_level(1, @_);
 }
 
@@ -62,69 +60,71 @@ sub encode ($$;$) {
 
     $text = join '', map { exists $encode_used{$_} ? $encode_used{$_} : $_ } split '', $text;
 
-    $text =~ s/([\_\.\^]?\w)\\shadda{}/$1$1/g;
-    $text =~ s/(\\ham{.})\\shadda{}/$1$1/g;
+    $text =~ s/([\_\.\^]?\w)\\shadda\{\}/$1$1/g;
+    $text =~ s/(\\ham\{.\})\\shadda\{\}/$1$1/g;
 
-    $text =~ s/([\=\s\-\%])\\alif{}\\vow{a}l/$1"al-/g;
-    $text =~ s/([\=\s\-\%])\\alif{}l/$1al-/g;
-    $text =~ s/(b\\vow{i})\\alif{}l/$1-al-/g;
-    $text =~ s/([\=\s\-\%])\\alif{}\\vow{([ui])}/$1"$2/g;
-    $text =~ s/([\=\s\-\%])\\alif{}/$1i/g;
-    $text =~ s/(\\vow{aN})\\alif{}/$1/g;
-    $text =~ s/\\alif{}(\\vow{aN})/$1/g;
-    $text =~ s/\\vow{a}\\alif{}/\\vow{A}/g;
-    $text =~ s/\\alif{}/\\aux{A}/g;
+    $text =~ s/([\=\s\-\%])\\alif\{\}\\vow\{a\}l/$1"al-/g;
+    $text =~ s/([\=\s\-\%])\\alif\{\}l/$1al-/g;
+    $text =~ s/(b\\vow\{i\})\\alif\{\}l/$1-al-/g;
+    $text =~ s/([\=\s\-\%])\\alif\{\}\\vow\{([ui])\}/$1"$2/g;
+    $text =~ s/([\=\s\-\%])\\alif\{\}/$1i/g;
+    $text =~ s/(\\vow\{aN\})\\alif\{\}/$1/g;
+    $text =~ s/\\alif\{\}(\\vow\{aN\})/$1/g;
+    $text =~ s/\\vow\{a\}\\alif\{\}/\\vow{A}/g;
+    $text =~ s/\\alif\{\}/\\aux{A}/g;
 
-    $text =~ s/\\madda{}/'A/g;
+    $text =~ s/\\madda\{\}/'A/g;
 
-    $text =~ s/\\vow{a}\\maq{}/\\vow{Y}/g;
-    $text =~ s/\\maq{}(\\vow{aN})/\\vow{aNY}/g;
-    $text =~ s/\\vow{aN}\\maq{}/\\vow{aNY}/g;
-    $text =~ s/\\maq{}/\\aux{Y}/g;
+    $text =~ s/\\vow\{a\}\\maq\{\}/\\vow{Y}/g;
+    $text =~ s/\\maq\{\}(\\vow\{aN\})/\\vow{aNY}/g;
+    $text =~ s/\\vow\{aN\}\\maq\{\}/\\vow{aNY}/g;
+    $text =~ s/\\maq\{\}/\\aux{Y}/g;
 
     $text =~ s/i(}?)y([^aiuAIUY])/I$1$2/g;  # produces \ham{I}, too
     $text =~ s/u(}?)w([^aiuAIUY])/U$1$2/g;
 
-    $text =~ s/([iIuU]})(\\ham{a})/$1-$2/g;
-    $text =~ s/([\-\s])\\ham{a}([^\\])/$1'\\aux{a}$2/g;
-    $text =~ s/([^\}\s])\\ham{a}/$1\\aux{a}'/g;
+    $text =~ s/([iIuU]})(\\ham\{a\})/$1-$2/g;
+    $text =~ s/([\-\s])\\ham\{a\}([^\\])/$1'\\aux{a}$2/g;
+    $text =~ s/([^\}\s])\\ham\{a\}/$1\\aux{a}'/g;
 
-    $text =~ s/([^\-\s])(\\ham{i})/$1-$2/g;
-    $text =~ s/\\ham{i}([^\\])/'\\aux{i}$1/g;
+    $text =~ s/([^\-\s])(\\ham\{i\})/$1-$2/g;
+    $text =~ s/\\ham\{i\}([^\\])/'\\aux{i}$1/g;
 
-    $text =~ s/([^\}])(\\ham{w})/$1\\aux{u}$2/g;
-    $text =~ s/(\\ham{w})([^\\])/$1\\aux{u}$2/g;
+    $text =~ s/([^\}])(\\ham\{w\})/$1\\aux{u}$2/g;
+    $text =~ s/(\\ham\{w\})([^\\])/$1\\aux{u}$2/g;
 
-    $text =~ s/([^\}])(\\ham{y})/$1\\aux{i}$2/g;
-    $text =~ s/(\\ham{y})([^\\])/$1\\aux{i}$2/g;
+    $text =~ s/([^\}])(\\ham\{y\})/$1\\aux{i}$2/g;
+    $text =~ s/(\\ham\{y\})([^\\])/$1\\aux{i}$2/g;
 
-    $text =~ s/\\ham{[aiwy]}/'/g;
-    $text =~ s/\\ham{I}/'I/g;
+    $text =~ s/\\ham\{[aiwy]\}/'/g;
+    $text =~ s/\\ham\{I\}/'I/g;
 
-    $text =~ s/(?<![^\=\s\-\%])\\aux{A}/\\aux{i}/g;
+    $text =~ s/(?<![^\=\s\-\%])\\aux\{A\}/\\aux{i}/g;
 
 
     no strict 'refs';
 
     if (defined ${ $cls . '::enmode' } and ${ $cls . '::enmode' } == 3) {
 
-        $text =~ s/\\vow{(.+?)}/$1/g;
-        $text =~ s/\\aux{(.+?)}/"$1/g;
-        $text =~ s/\\sukun{}/"/g;
+        $text =~ s/\\vow\{(.+?)\}/$1/g;
+        $text =~ s/\\aux\{(.+?)\}/"$1/g;
+        $text =~ s/\\sukun\{\}/"/g;
     }
     elsif (defined ${ $cls . '::enmode' } and ${ $cls . '::enmode' } == 2) {
 
-        $text =~ s/\\vow{(.+?)}/"$1/g;
-        $text =~ s/\\aux{(.+?)}/$1/g;
-        $text =~ s/\\sukun{}/"/g;
+        $text =~ s/\\vow\{(.+?)\}/"$1/g;
+        $text =~ s/\\aux\{(.+?)\}/$1/g;
+        $text =~ s/\\sukun\{\}/"/g;
     }
     elsif (defined ${ $cls . '::enmode' } and ${ $cls . '::enmode' } == 4) {
 
-        $text =~ s/\\vow{(.+?)}/$1/g;
-        $text =~ s/\\aux{(.+?)}/$1/g;
-        $text =~ s/\\sukun{}//g;
+        $text =~ s/\\vow\{(.+?)\}/$1/g;
+        $text =~ s/\\aux\{(.+?)\}/$1/g;
+        $text =~ s/\\sukun\{\}//g;
     }
 
+    $text = Encode::encode "utf8", $text if Encode::is_utf8($text);
+
     return $text;
 }
 
@@ -135,6 +135,8 @@ sub decode ($$;$) {
 
     $_[1] = '' if $check;                   # this is what in-place edit needs
 
+    $text = Encode::decode "utf8", $text unless Encode::is_utf8($text);
+
     $cls->initialize_decode() unless %decode_used;
 
     $text = "\n" . $text . "\n";
@@ -155,19 +157,19 @@ sub decode ($$;$) {
     $text =~ s/([\s\-])'([iI])/$1\\H{i}$2/gs;
     $text =~ s/([\s\-])'A/$1\\M{}/gs;
 
-    $text =~ s/(I|y\\O{})'(aN[AY]?[\s\-])/$1\\H{y}$2/gs;
-    $text =~ s/a'(|\\D{})(|[au]N?)([\s\-])/a\\H{a}$1$2$3/gs;
-    $text =~ s/a'(|\\D{})(iN?)([\s\-])/a\\H{i}$1$2$3/gs;
-    $text =~ s/i'(|\\D{})(|[aiu]N?)([\s\-])/i\\H{y}$1$2$3/gs;
-    $text =~ s/u'(|\\D{})(|[aiu]N?)([\s\-])/u\\H{w}$1$2$3/gs;
-    $text =~ s/'(|\\D{})(|[aiu]N?)([\s\-])/\\H{}$1$2$3/gs;
+    $text =~ s/(I|y\\O\{\})'(aN[AY]?[\s\-])/$1\\H{y}$2/gs;
+    $text =~ s/a'(|\\D\{\})(|[au]N?)([\s\-])/a\\H{a}$1$2$3/gs;
+    $text =~ s/a'(|\\D\{\})(iN?)([\s\-])/a\\H{i}$1$2$3/gs;
+    $text =~ s/i'(|\\D\{\})(|[aiu]N?)([\s\-])/i\\H{y}$1$2$3/gs;
+    $text =~ s/u'(|\\D\{\})(|[aiu]N?)([\s\-])/u\\H{w}$1$2$3/gs;
+    $text =~ s/'(|\\D\{\})(|[aiu]N?)([\s\-])/\\H{}$1$2$3/gs;
 
-    $text =~ s/([iI]|y\\O{})'(|\\D{})/$1\\H{y}$2/g;
-    $text =~ s/'(|\\D{})([iI])/\\H{y}$1$2/g;
-    $text =~ s/([uU])'(|\\D{})/$1\\H{w}$2/g;
-    $text =~ s/'(|\\D{})([uU])/\\H{w}$1$2/g;
-    $text =~ s/A'(|\\D{})/A\\H{}$1/g; # how do you write <rA''AsuN>?
-    $text =~ s/a'(\\D{})/a\\H{a}$1/g; # how do you write <ra''AsuN>?
+    $text =~ s/([iI]|y\\O\{\})'(|\\D\{\})/$1\\H{y}$2/g;
+    $text =~ s/'(|\\D\{\})([iI])/\\H{y}$1$2/g;
+    $text =~ s/([uU])'(|\\D\{\})/$1\\H{w}$2/g;
+    $text =~ s/'(|\\D\{\})([uU])/\\H{w}$1$2/g;
+    $text =~ s/A'(|\\D\{\})/A\\H{}$1/g; # how do you write <rA''AsuN>?
+    $text =~ s/a'(\\D\{\})/a\\H{a}$1/g; # how do you write <ra''AsuN>?
     $text =~ s/'A/\\M{}/g;
     $text =~ s/'a/\\H{a}a/g;
     $text =~ s/'Y/\\H{a}Y/g;
@@ -179,7 +181,7 @@ sub decode ($$;$) {
     # alas! using $one in the replacing expression produces extra \\
 
     $text =~ s/aNY/\\V{aN}\\Q{}/g;
-    $text =~ s/(?<=A\\H{}|\\H{a})aN/\\V{aN}/g;
+    $text =~ s/(?<=A\\H\{\}|\\H\{a\})aN/\\V{aN}/g;
     $text =~ s/(?<=T)aN/\\V{aN}/g;
 
     $text =~ s/(?<!{)aNA?/\\V{aN}\\L{}/g;
@@ -404,11 +406,6 @@ __END__
 Encode::Arabic::ArabTeX::RE - Deprecated Encode::Arabic::ArabTeX implemented with regular expressions
 
 
-=head1 REVISION
-
-    $Revision: 162 $        $Date: 2006-12-16 01:16:10 +0100 (Sat, 16 Dec 2006) $
-
-
 =head1 SYNOPSIS
 
     use Encode::Arabic::ArabTeX::RE;
@@ -437,16 +434,12 @@ L<Encode::Arabic::ArabTeX|Encode::Arabic::ArabTeX>
 
 =head1 AUTHOR
 
-Otakar Smrz, L<http://ufal.mff.cuni.cz/~smrz/>
-
-    eval { 'E<lt>' . ( join '.', qw 'otakar smrz' ) . "\x40" . ( join '.', qw 'mff cuni cz' ) . 'E<gt>' }
-
-Perl is also designed to make the easy jobs not that easy ;)
+Otakar Smrz C<< <otakar-smrz users.sf.net> >>, L<http://otakar-smrz.users.sf.net/>
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2006 by Otakar Smrz
+Copyright (C) 2003-2016 Otakar Smrz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
