@@ -2,10 +2,10 @@
 #
 # Encoding of Arabic: ArabTeX Notation by Klaus Lagally, ZDMG #################################
 
-# $Id: ZDMG.pm 808 2009-02-09 23:19:07Z smrz $
-
 package Encode::Arabic::ArabTeX::ZDMG;
 
+our $VERSION = '14.1';
+
 use 5.008;
 
 use strict;
@@ -13,9 +13,6 @@ use warnings;
 
 use Carp;
 
-our $VERSION = do { q $Revision: 808 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
-
-
 use Encode::Arabic::ArabTeX ();
 use base 'Encode::Arabic::ArabTeX';
 
@@ -79,7 +76,9 @@ sub import {            # perform import as if Encode were used one level before
 
     require Encode;
 
-    Encode->export_to_level(1, @_);     # here comes the only trick ^^
+    push @Encode::ISA, 'Exporter' unless Encode->can('export_to_level');
+
+    Encode->export_to_level(1, @_);
 }
 
 
@@ -274,6 +273,7 @@ sub decoder ($;$$) {
                     [   "_aI",      "\x{0061}\x{0304}"  ],  #   "\x{0101}"
                     [   "A",        "\x{0061}\x{0304}"  ],  #   "\x{0101}"
                     [   "^A",       "\x{0061}\x{0304}"  ],  #   "\x{0101}"
+                    [   "_A",       "\x{0061}\x{0304}"  ],  #   "\x{0101}"
                     [   "e",        "\x{0065}"          ],
                     [   "E",        "\x{0065}\x{0304}"  ],  #   "\x{0113}"
                     [   "i",        "\x{0069}"          ],
@@ -377,6 +377,8 @@ sub decoder ($;$$) {
 
                 # silence the silent
 
+                    "_W",           "",
+
                     "WA",           [ "", "W" ],
 
                     "UW",           [ "", "U" ],
@@ -574,11 +576,6 @@ __END__
 Encode::Arabic::ArabTeX::ZDMG - ZDMG phonetic transcription of Arabic using the ArabTeX notation
 
 
-=head1 REVISION
-
-    $Revision: 808 $        $Date: 2009-02-10 00:19:07 +0100 (Tue, 10 Feb 2009) $
-
-
 =head1 SYNOPSIS
 
     use Encode::Arabic::ArabTeX::ZDMG;  # imports just like 'use Encode' would, plus extended options
@@ -629,16 +626,12 @@ Encode Arabic: Exercise in Functional Parsing
 
 =head1 AUTHOR
 
-Otakar Smrz, L<http://ufal.mff.cuni.cz/~smrz/>
-
-    eval { 'E<lt>' . ( join '.', qw 'otakar smrz' ) . "\x40" . ( join '.', qw 'mff cuni cz' ) . 'E<gt>' }
-
-Perl is also designed to make the easy jobs not that easy ;)
+Otakar Smrz C<< <otakar-smrz users.sf.net> >>, L<http://otakar-smrz.users.sf.net/>
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2009 by Otakar Smrz
+Copyright (C) 2003-2010 Otakar Smrz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
